@@ -9,6 +9,7 @@
 #' @param allow_failure logical - whether to proceed or stop on failure. By default set to TRUE (i.e. don't stop on error). 
 #' For debugging purposes change to FALSE
 #' @importFrom XML readHTMLTable
+#' @importFrom utils object.size
 #' 
 #' @export
 #' 
@@ -25,7 +26,7 @@
 ogimet_hourly = function(date = c(Sys.Date() - 30, Sys.Date()), 
                          coords = FALSE,
                          station = 12330,
-                         precip_split = TRUE, 
+                         precip_split = TRUE,
                          allow_failure = TRUE) {
   
   if (allow_failure) {
@@ -83,7 +84,7 @@ ogimet_hourly_bp = function(date = date,
     )
 
   for (station_nr in station) {
-    message(station_nr)
+    message(paste("station: ", station_nr))
     # adding progress bar if at least 3 iterations are needed
     if (length(dates)*length(station) >= 3 ) pb = txtProgressBar(min = 0, max = length(dates)*length(station) - 1, style = 3)
     
@@ -119,14 +120,19 @@ ogimet_hourly_bp = function(date = date,
                                        sep = "")
       }
       
-      temp = tempfile()
-      test_url(linkpl2, temp)
+      body = httr::GET(linkpl2,
+                    httr::add_headers(
+                      `User-Agent` = "Mozilla/5.0 (Macintosh; Intel Mac OS X 10.15; rv:143.0) Gecko/20100101 Firefox/143.0",
+                      `Accept` = "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8",
+                      `Accept-Language` = "pl,en-US;q=0.7,en;q=0.3",
+                      `Referer` = "https://ogimet.com/resynops.phtml.en",
+                      `Cookie` = "cookieconsent_status=dismiss; ogimet_serverid=huracan|aNaPt|aNaPj"
+                      ))
+      body = httr::content(body, as = "text", encoding = "UTF-8")
       
-      # run only if downloaded file is valid
-      if (!is.na(file.size(temp)) & (file.size(temp) > 100)) {
-        #a = getURL(linkpl2)
-        a = readHTMLTable(temp, stringsAsFactors = FALSE)
-        unlink(temp)
+      # run only if downloaded object is valid
+      if (object.size(body) > 1000) {
+        a = readHTMLTable(body)
         b = a[[length(a)]]
         
         if (is.null(b)) {
@@ -148,7 +154,10 @@ ogimet_hourly_bp = function(date = date,
         # to avoid gtools::smartbind function or similar from another package..
         if (ncol(data_station) >= ncol(b)) {
           b[setdiff(names(data_station), names(b))] = NA # adding missing columns
-          data_station = rbind(data_station, b)  # joining data
+          data_station = as.data.frame(
+            data.table::rbindlist(
+            list(data_station, b), fill = TRUE, use.names = TRUE)
+            )  # joining data
   
         } else { # when b have more columns then data_station
           if (nrow(data_station) == 0) {
@@ -161,8 +170,8 @@ ogimet_hourly_bp = function(date = date,
   
           if (coords) {
           coord = a[[1]][2, 1]
-          data_station["Lon"] = get_coord_from_string(coord, "Longitude")
-          data_station["Lat"] = get_coord_from_string(coord, "Latitude")
+          data_station$Lon = get_coord_from_string(coord, "Longitude")
+          data_station$Lat = get_coord_from_string(coord, "Latitude")
         }
         
       } # end of checking for empty files / problems with connection
