@@ -1,17 +1,19 @@
 #' Download file in a graceful way
 #'
 #' Function for downloading & testing url/internet connection according to CRAN policy
-#' Example solution strongly based on https://community.rstudio.com/t/internet-resources-should-fail-gracefully/49199/12
+#' Example solution strongly based on 
+#' https://community.rstudio.com/t/internet-resources-should-fail-gracefully/49199/12
 #' as suggested by kvasilopoulos
 #' 
 #' @param link character vector with URL to check
 #' @param output character vector for output file name
-#' @param quiet logical vector (TRUE or FALSE) to be passed to curl_download function. FALSE by default
+#' @param quiet logical vector (TRUE or FALSE) to be passed to curl_download function. 
+#' FALSE by default
 #'
 #' @importFrom curl curl_download 
 #' @importFrom curl has_internet
 #' @import httr
-#' 
+#' @return No return value, called for side effects
 #' @export
 #'
 #' @examples
@@ -22,10 +24,7 @@
 #' }
 #'
 
-
-
 test_url = function(link, output, quiet = FALSE) {
-  print(link)
   try_GET = function(x, ...) {
     tryCatch(
       curl::curl_download(url = link, destfile = output, mode = "wb", quiet = quiet, ...),
@@ -54,17 +53,4 @@ test_url = function(link, output, quiet = FALSE) {
     message(paste0("\nCheck: ", link, " in your browser!\n"))
     return(invisible(NULL))
   }
- 
 }
-
-# b = gracefully_fail("http://httpbin.org/status/404") # http >400
-# #> Not Found (HTTP 404).
-# gracefully_fail("http://httpbin.org/delay/11") # Timeout
-# #> Timeout was reached: [httpbin.org] Operation timed out after 1000 milliseconds with 0 bytes received
-# a = gracefully_fail("http://httpbin.org") #OK
-# 
-# b = curl_download(url = "http://httpbin.org", destfile = tempfile())
-# b = curl_download(url = "http://httpbin.org/status/404", destfile = tempfile())
-# 
-# url = "http://www2.census.gov/acs2011_5yr/pums/csv_pus.zip"
-# test_url(link = url, output = tempfile())
